<?php
/*  Copyright 2013  Etalia  (tech@etalia.net)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


function etalia_adminMenu() {
    add_options_page('Etalia Options', 'Etalia', 'administrator', 'etalia', 'etalia_settings');
}


function _etalia_getPublications($auth) {
    if (!$auth) {
        $auth = etalia_getAuthorization();
    }
    $ch = curl_init(); 
    curl_setopt($ch, CURLOPT_URL, ETALIA_SERVER."/journalia");
    curl_setopt($ch, CURLOPT_HTTPGET, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array("Authorization: Etalia ".$auth));
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    $json = json_decode(curl_exec($ch), true);
    curl_close($ch);
    $publications = array();
    foreach ($json['data'] as $section) {
        if (($section['title'] == "_myJournals" || $section['title'] == "_sharedJournals")
          && $section['@entity'] == "Static") {
            foreach ($section['data'] as $publication) {
                if (substr($publication['id'], 0, 1) == "p") {
                    $publications[$publication['id']] = $publication['title'];
                }
            }
        }
    }
    return $publications;
}


function etalia_settings() {
    $authorized = false;
    $submitted = $_POST["submitted"];
    $acc_email = $_POST["email"] ? $_POST["email"] : etalia_getEmail();
    update_option(ETALIA_ACCOUNT_EMAIL, $acc_email);
    $acc_password = $_POST["password"];
    if ($acc_password != '' && $acc_password != '************') {
        $acc_password = base64_encode(md5($acc_password, true));
        update_option(ETALIA_ACCOUNT_PASSWORD, $acc_password);
    } else {
        $acc_password = etalia_getPassword();
    }
    $auth = null;
    if ($acc_email && $acc_password) {
        $auth = etalia_getAuthorization();
    }
    if ($auth) {
        $publications = _etalia_getPublications($auth);
        $publication = $_POST["publication"];
        $use_signer = $_POST["signer"];
        $link_to_post = $_POST["linkToPost"];
        $lang = $_POST["lang"];
        if ($submitted) {
            update_option(ETALIA_ACCOUNT_EMAIL, $acc_email);
            update_option(ETALIA_PUBLICATION, $publication);
            update_option(ETALIA_USE_SIGNER, $use_signer);
            update_option(ETALIA_LINK_TO_POST, $link_to_post);
            update_option(ETALIA_LANG, $lang);
            ?><div class="updated"><p><strong>Options Saved</strong></p></div><?php
        }
    } else if ($submitted) {
        delete_option(ETALIA_ACCOUNT_EMAIL);
        delete_option(ETALIA_ACCOUNT_PASSWORD);
        ?><div class="error"><p><strong>Wrong Credentials</strong></p></div><?php
    }
?>
  <div class="wrap">
    <div id="icon-options-general" class="icon32"><br /></div> 
    <h2>Etalia Settings</h2>
    <form action="" method="post" name="etaliasettings">
      <input type="hidden" name="submitted" value="true"/>
      <table class="form-table">
        <tr>
          <td colspan="2">
            You must enter your Etalia credentials so the plugin can publish the contents. The password will be stored encrypted.
          </td>
        </tr>
        <tr valign="top">
          <th scope="row">
            <label for="etalia_email">email</label>
          </th>
          <td>
            <input name="email" type="text" id="etalia_email" value="<?php echo etalia_getEmail(); ?>" class="regular-text" />
          </td>
        </tr>
        <tr valign="top">
          <th scope="row">
            <label for="etalia_password">password</label>
          </th>
          <td>
            <input name="password" type="password" id="etalia_password" value="<?php if (etalia_getPassword()) echo '************'; ?>" class="regular-text" />
          </td>
        </tr>
        <?php if ($auth) {?>
        <tr valign="top">
          <th scope="row">
            <label for="etalia_publication">journal</label>
          </th>
          <td>
            <select name="publication" id="etalia_publication">
              <option value="">- Not Assigned -</option>
              <?php 
              foreach ($publications as $id => $title) {
                  ?><option value="<?php echo $id; ?>" <?php if (etalia_getPublication() == $id) echo 'selected'; ?>><?php echo $title; ?></option><?php
              }
              ?>
            </select>
            <p class="description">If you want to assign the published contents to a Journal choose one.</p>
          </td>
        </tr>
        <tr valign="top">
          <th scope="row">
            <label for="etalia_lang">language</label>
          </th>
          <td>
            <select name="lang" id="etalia_lang">
              <option value="it">IT</option>
              <option value="en">EN</option>
            </select>
          </td>
        </tr>
        <tr valign="top">
          <th scope="row">
            <label for="etalia_signer">Use post author as signer</label>
          </th>
          <td>
            <input name="signer" type="checkbox" id="etalia_signer" value="true" <?php if (etalia_getUseSigner()) echo 'checked="checked"'; ?> />
            <p class="description">If checked the author on Etalia will be the post author's name used as alias and the content on Etalia will not be attributable to the owner.</p>
          </td>
        </tr>
        <tr valign="top">
          <th scope="row">
            <label for="etalia_link_to_post">Link to original post</label>
          </th>
          <td>
            <input name="linkToPost" type="checkbox" id="etalia_link_to_post" value="true" <?php if (etalia_getLinkToPost()) echo 'checked="checked"'; ?> />
            <p class="description">If checked, on Etalia content detail page will appear a link to the original blog post.</p>
          </td>
        </tr>
        <?php } ?>
      </table>
      <p class="submit">
        <input type="submit" name="Submit" class="button-primary" value="Save Changes" />
      </p>
    </form>
  </div>
<?php
}

/*
delete_option(ETALIA_ACCOUNT_ID);
delete_option(ETALIA_ACCOUNT_EMAIL);
delete_option(ETALIA_ACCOUNT_PASSWORD);
delete_option(ETALIA_PUBLICATION);
delete_option(ETALIA_USE_SIGNER);
delete_option(ETALIA_LINK_TO_POST);
/*/

?>
