<?php
/*
Plugin Name: Etalia
Plugin URI: http://www.etalia.net
Description: Etalia publishing integration.
Version: 1.0.1
Author: Daniele Madama
Author URI: http://www.danysoft.org

    Copyright 2013  Etalia  (tech@etalia.net)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


// Load all of the definitions that are needed
etalia_init();
// Run after the plugins are loaded
add_action('plugins_loaded', 'etalia_run', 1);


/**
Install the plugin
*/
function etalia_install() {
}

// Register install
add_action('etalia/etalia.php', 'etalia_install');


/**
Init
*/
function etalia_init() {
    define('ETALIA_SERVER', 'https://api.etalia.net');
    define('ETALIA_ACCOUNT_EMAIL', 'etalia_account_email');
    define('ETALIA_ACCOUNT_PASSWORD', 'etalia_account_password');
    define('ETALIA_PUBLICATION', 'etalia_publication');
    define('ETALIA_USE_SIGNER', 'etalia_use_signer');
    define('ETALIA_LANG', 'etalia_lang');
    define('ETALIA_LINK_TO_POST', 'etalia_link_to_post');
    require_once('etalia-common.php');
    if (is_admin()) {
        require_once('etalia-admin.php');
    }
}


/**
Run
*/
function etalia_run() {
    add_action('publish_post', 'etalia_publish');
    // If admin, initialise the Admin functionality
    if (is_admin()) {
        add_action('admin_menu', 'etalia_adminMenu');
    }
}


/**
Publish post to Etalia
*/
function etalia_publish($post_id) {
    if( ( $_POST['post_status'] == 'publish' ) && ( $_POST['original_post_status'] != 'publish' ) ) {
        $auth = etalia_getAuthorization();
        if (!$auth) {
            return;
        }
        $post = get_post($post_id);
        $article['@entity'] = "Article";
        $article['title'] = $post->post_title;
        // Get HTML content
        $content = trim(stripslashes($post->post_content));
        $content = apply_filters("the_content", $content);
        $article['body'] = $content;
        if (etalia_getUseSigner()) {
            $author = get_userdata($post->post_author);
            $article['signer'] = $author->display_name;
        }
        if (etalia_getLinkToPost()) {
            $article['originalUrl'] = get_permalink($post->ID);
        }
        if (etalia_getPublication()) {
            $publication['@entity'] = "PublicationStandard";
            $publication['id'] = etalia_getPublication();
            $article['publication'] = $publication;
        }
        $article['lang'] = etalia_getLang();
        $article['gallery'] = _etalia_get_post_images($content);
        $article['published'] = true;
        $article['searchable'] = true;
        $json = json_encode($article);
        $ch = curl_init(); 
        curl_setopt($ch, CURLOPT_URL, ETALIA_SERVER."/content/article");
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
        curl_setopt($ch, CURLOPT_POSTFIELDS, $json);
        curl_setopt($ch, CURLOPT_HTTPHEADER, 
            array(
                "Authorization: Etalia ".$auth,
                "Content-Type: application/json",
                "Content-Length: ".strlen($json)));
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        $json = json_decode(curl_exec($ch), true);
        curl_close($ch);
    }
}


/**
Extract img tags and prepare gallery
*/
function _etalia_get_post_images($content) {
    $query_images_args = array('post_type' => 'attachment', 'post_mime_type' =>'image', 'post_status' => 'inherit', 'posts_per_page' => -1,'numberposts' => 1);
    $query_images = new WP_Query($query_images_args);
    $medias = array();
    foreach ($query_images->posts as $image) {
        $media['@entity'] = "Media";
        $media['type'] = "_image";
        $media['url'] = wp_get_attachment_url($image->ID);
        $media['description'] = $image->post_content;
        $medias[] = $media;
    }
    $content_images = strip_tags($content, '<img>');
    $dom = new DOMDocument();
    $dom->loadHTML($content_images);
    $gallery = array();
    foreach ($dom->getElementsByTagName('img') as $img) {
        $img_url = $img->getAttribute('src');
        $description = $img->getAttribute('alt');
        $media = array();
        foreach ($medias as $element) {
            if (substr($img_url, 0, strrpos($element['url'], '.')) == substr($element['url'], 0, strrpos($element['url'], '.'))) {
                $description = $element['description'];
            }
        }
        $media['@entity'] = "Media";
        $media['type'] = "_image";
        $media['url'] = $img_url;
        $media['description'] = $description;
        $gallery[] = $media;
    }
    return $gallery;
}

?>
